singledir

package
v0.0.0-...-d7252a8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 6, 2023 License: GPL-3.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Hmd5

func Hmd5(path string) []byte

Hash md5sum Return the md5sum for a normal file, and for a directory, in this last case I use the full path as input string for the md5 algorithm, using the rationale of not posible repeated directory names.

func Hsha512

func Hsha512(path string) []byte

Return the sha512 for a normal file, and for a directory, in this last case I use the full path as input string for sha512 algoritm, using the rationale of not posible repeated directory names.

func ReadDirNames

func ReadDirNames(dirpath string) ([]string, error)

If the input is a directory, return the list of files.

func ToAbs

func ToAbs(basepath string, paths []string) ([]string, error)

Get the local paths and transform this to absolute path. If the path is "." calculate the absolute path from the file execution, else, use the original basepath and concatenate with the files inside this.

Types

This section is empty.

Jump to