Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Hmd5 ¶
Hash md5sum Return the md5sum for a normal file, and for a directory, in this last case I use the full path as input string for the md5 algorithm, using the rationale of not posible repeated directory names.
func Hsha512 ¶
Return the sha512 for a normal file, and for a directory, in this last case I use the full path as input string for sha512 algoritm, using the rationale of not posible repeated directory names.
func ReadDirNames ¶
If the input is a directory, return the list of files.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.